@@ -1,6 +1,10 @@
-from unittest import TestCase
+# -*- coding: utf-8 -*-
+
 import warnings
 
+from mock import patch, Mock
+from pytest import raises
+
 from pyramid.interfaces import IAuthenticationPolicy
 from pyramid.interfaces import IAuthorizationPolicy
 from pyramid.interfaces import IView
@@ -12,40 +16,21 @@ from zope.interface import implementedBy
 from zope.interface import providedBy
 
 from kotti.testing import TestingRootFactory
-from kotti.testing import UnitTestBase
 from kotti.testing import testing_db_url
 
 
-def _includeme_login(config):
-    config.add_view(
-        _login_view,
-        name='login',
-        renderer='kotti:templates/login.pt',
-        )
+# filter deprecation warnings for code that is still tested...
+from warnings import filterwarnings
+filterwarnings('ignore', "^The 'kotti.includes' setting")
 
 
-def _includeme_layout(config):
-    # override edit master layout with view master layout
-    config.override_asset(
-        to_override='kotti:templates/edit/master.pt',
-        override_with='kotti:templates/view/master.pt',
-        )
+class TestApp:
 
-
-def _login_view(request):
-    return {}  # pragma: no cover
-
-
-def _dummy_search(search_term, request):
-    return u"Not found. Sorry!"
-
-
-class TestApp(UnitTestBase):
     def required_settings(self):
         return {'sqlalchemy.url': testing_db_url(),
                 'kotti.secret': 'dude'}
 
-    def test_override_settings(self):
+    def test_override_settings(self, db_session):
         from kotti import main
         from kotti import get_settings
 
@@ -58,107 +43,166 @@ class TestApp(UnitTestBase):
 
         settings = self.required_settings()
         settings['kotti.configurators'] = [my_configurator]
-        main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            main({}, **settings)
 
-        self.assertEqual(get_settings()['kotti.base_includes'], [])
-        self.assertEqual(get_settings()['kotti.available_types'], [MyType])
+        assert get_settings()['kotti.base_includes'] == []
+        assert get_settings()['kotti.available_types'] == [MyType]
 
-    def test_auth_policies_no_override(self):
+    def test_auth_policies_no_override(self, db_session):
         from kotti import main
 
         settings = self.required_settings()
-        main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            main({}, **settings)
 
         registry = get_current_registry()
         assert registry.queryUtility(IAuthenticationPolicy) is not None
         assert registry.queryUtility(IAuthorizationPolicy) is not None
 
-    def test_auth_policies_override(self):
+    def test_auth_policies_override(self, db_session):
         from kotti import main
 
         settings = self.required_settings()
         settings['kotti.authn_policy_factory'] = 'kotti.none_factory'
         settings['kotti.authz_policy_factory'] = 'kotti.none_factory'
-        main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            main({}, **settings)
 
         registry = get_current_registry()
         assert registry.queryUtility(IAuthenticationPolicy) is None
         assert registry.queryUtility(IAuthorizationPolicy) is None
 
-    def test_asset_overrides(self):
+    def test_asset_overrides(self, db_session):
         from kotti import main
 
         settings = self.required_settings()
         settings['kotti.asset_overrides'] = 'pyramid:scaffold/ pyramid.fixers'
-        main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            main({}, **settings)
 
-    def test_kotti_includes_deprecation_warning(self):
+    def test_kotti_static_deprecated(self):
+        with warnings.catch_warnings(record=True) as w:
+            from kotti.static import edit_needed
+            edit_needed  # pyflakes
+            assert len(w) == 1
+            assert issubclass(w[-1].category, DeprecationWarning)
+            msg = str(w[-1].message)
+            assert "The module kotti.static has been moved to kotti.fanstatic as of Kotti" in msg
+
+    def test_kotti_static_needed_deprecation_warning(self, db_session):
         from kotti import main
 
         settings = self.required_settings()
-        settings['kotti.includes'] = (
-            'kotti.tests.test_app._includeme_layout')
+        settings['kotti.static.view_needed'] = (' kotti.fanstatic.view_needed')
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter('always')
-            main({}, **settings)
+            with patch('kotti.resources.initialize_sql'):
+                main({}, **settings)
+            assert len(w) == 1
+            assert issubclass(w[-1].category, DeprecationWarning)
+            msg = str(w[-1].message)
+            assert "The 'kotti.static.view_needed' setting has been deprecated" in msg
+
+    def test_kotti_static_needed_merged_to_kotti_fanstatic_needed(self, db_session):
+        from kotti import main
+
+        settings = self.required_settings()
+        settings['kotti.static.needed'] = 'kotti.fanstatic.edit_needed'
+
+        with patch('kotti.resources.initialize_sql'):
+            app = main({}, **settings)
+
+        groups = app.registry.settings['kotti.fanstatic.view_needed']
+        resource_names = [[r.relpath for r in group.resources] for group in groups]
+        resource_names = [name for names in resource_names for name in names]
+        assert 'view.css' in resource_names
+
+        settings = self.required_settings()
+        settings['kotti.fanstatic.view_needed'] = 'kotti.fanstatic.view_needed'
+        settings['kotti.static.view_needed'] = ' kotti.fanstatic.edit_needed'
+        with warnings.catch_warnings(record=True):
+            with patch('kotti.resources.initialize_sql'):
+                app = main({}, **settings)
+        regsettings = app.registry.settings
+
+        assert len(regsettings['kotti.fanstatic.view_needed']) == 2
+
+        with raises(KeyError):
+            regsettings['kotti.static.view_needed']
+
+        groups = regsettings['kotti.fanstatic.view_needed']
+        resource_names = [[r.relpath for r in group.resources] for group in groups]
+        resource_names = [name for names in resource_names for name in names]
+        assert 'edit.css' in resource_names
+
+    def test_kotti_includes_deprecation_warning(self, db_session):
+        from kotti import main
+
+        settings = self.required_settings()
+        settings['kotti.includes'] = ('kotti.testing.includeme_layout')
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always')
+            with patch('kotti.resources.initialize_sql'):
+                main({}, **settings)
             assert len(w) == 1
             assert issubclass(w[-1].category, DeprecationWarning)
             msg = str(w[-1].message)
             assert "The 'kotti.includes' setting has been deprecated" in msg
 
-    def test_kotti_includes_merged_to_pyramid_includes(self):
+    def test_kotti_includes_merged_to_pyramid_includes(self, db_session):
         from kotti import main
 
         settings = self.required_settings()
-        settings['kotti.includes'] = (
-            'kotti.tests.test_app._includeme_login')
+        settings['kotti.includes'] = ('kotti.testing.includeme_login')
 
-        app = main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            app = main({}, **settings)
         assert (app.registry.settings['pyramid.includes'].strip() ==
-                'kotti.tests.test_app._includeme_login')
+                'kotti.testing.includeme_login')
 
         settings = self.required_settings()
-        settings['pyramid.includes'] = (
-            'kotti.tests.test_app._includeme_layout')
-        settings['kotti.includes'] = (
-            'kotti.tests.test_app._includeme_login')
-        app = main({}, **settings)
+        settings['pyramid.includes'] = ('kotti.testing.includeme_layout')
+        settings['kotti.includes'] = ('kotti.testing.includeme_login')
+        with patch('kotti.resources.initialize_sql'):
+            app = main({}, **settings)
         regsettings = app.registry.settings
         assert len(regsettings['pyramid.includes'].split()) == 2
         assert settings['kotti.includes'] in regsettings['pyramid.includes']
 
-    def test_pyramid_includes_overrides_base_includes(self):
+    def test_pyramid_includes_overrides_base_includes(self, root):
         from kotti import main
-        from kotti.resources import get_root
 
         settings = self.required_settings()
-        settings['pyramid.includes'] = (
-            'kotti.tests.test_app._includeme_login')
-        app = main({}, **settings)
+        settings['pyramid.includes'] = ('kotti.testing.includeme_login')
+        with patch('kotti.resources.initialize_sql'):
+            app = main({}, **settings)
 
         provides = [
             IViewClassifier,
             implementedBy(Request),
-            providedBy(get_root()),
+            providedBy(root),
             ]
         view = app.registry.adapters.lookup(provides, IView, name='login')
-        assert view.__module__ == __name__
+        assert view.__module__ == 'kotti.testing'
 
-    def test_use_tables(self):
+    def test_use_tables(self, db_session):
         from kotti import main
 
         settings = self.required_settings()
         settings['kotti.populators'] = ''
         settings['kotti.use_tables'] = 'principals'
-        main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            main({}, **settings)
 
-    def test_root_factory(self):
+    def test_root_factory(self, db_session):
         from kotti import main
-        from kotti.resources import get_root
+        from kotti.resources import get_root    # the `root` fixture doesn't work here
 
         settings = self.required_settings()
         settings['kotti.root_factory'] = (TestingRootFactory,)
-        app = main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            app = main({}, **settings)
         assert isinstance(get_root(), TestingRootFactory)
         assert isinstance(app.root_factory(), TestingRootFactory)
 
@@ -168,19 +212,19 @@ class TestApp(UnitTestBase):
         settings = settings or self.required_settings()
         settings['kotti.root_factory'] = (TestingRootFactory,)
         settings['kotti.site_title'] = 'My Site'
-        app = main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            app = main({}, **settings)
 
         request = Request.blank('/@@login')
         (status, headers, response) = request.call_application(app)
         assert status == '200 OK'
 
-    def test_render_master_view_template_minimal_root(self):
+    def test_render_master_view_template_minimal_root(self, db_session):
         settings = self.required_settings()
-        settings['pyramid.includes'] = (
-            'kotti.tests.test_app._includeme_layout')
+        settings['pyramid.includes'] = ('kotti.testing.includeme_layout')
         return self.test_render_master_edit_template_minimal_root(settings)
 
-    def test_setting_values_as_unicode(self):
+    def test_setting_values_as_unicode(self, db_session):
         from kotti import get_settings
         from kotti import main
 
@@ -189,33 +233,38 @@ class TestApp(UnitTestBase):
         settings['kotti_foo.site_title'] = 'K\xc3\xb6tti'
         settings['foo.site_title'] = 'K\xc3\xb6tti'
 
-        main({}, **settings)
+        with patch('kotti.resources.initialize_sql'):
+            main({}, **settings)
         assert get_settings()['kotti.site_title'] == u'K\xf6tti'
         assert get_settings()['kotti_foo.site_title'] == u'K\xf6tti'
         assert get_settings()['foo.site_title'] == 'K\xc3\xb6tti'
 
-    def test_search_content(self):
+    def test_search_content(self, db_session):
         from kotti import main
         from kotti.views.util import search_content
 
         settings = self.required_settings()
-        settings['kotti.search_content'] = 'kotti.tests.test_app._dummy_search'
-        main({}, **settings)
+        settings['kotti.search_content'] = 'kotti.testing.dummy_search'
+        with patch('kotti.resources.initialize_sql'):
+            main({}, **settings)
         assert search_content(u"Nuno") == u"Not found. Sorry!"
 
-    def test_stamp_heads(self):
+    def test_stamp_heads(self, db_session, connection):
         from kotti import main
-        from kotti import DBSession
 
         settings = self.required_settings()
-        main({}, **settings)
+        engine = connection.engine
+        engine.table_names = Mock(return_value=[])
+        with patch('kotti.engine_from_config', return_value=engine):
+            with patch('kotti.resources.metadata'):
+                main({}, **settings)
 
-        res = DBSession.execute(select(
+        res = db_session.execute(select(
             columns=['version_num'], from_obj=['kotti_alembic_version']))
         assert tuple(res)  # a version_num should exist
 
 
-class TestGetVersion(TestCase):
+class TestGetVersion:
     def test_it(self):
         from kotti import get_version
         assert isinstance(get_version(), str)
